@@ -65,7 +65,7 @@ splith p (n:ns) = case n `quotRemInteger` p of
 #if defined(INTEGER_GMP) || defined(INTEGER_SIMPLE)
   (# q, r #) ->
 #else
-  (q, r) -> 
+  (q, r) ->
 #endif
           if q > 0
             then q : r : splitb p ns
@@ -124,8 +124,8 @@ showpIntAtBase :: Integral a => a -> (Int -> Char) -> a -> Put
 showpIntAtBase b f n | n < 0     = putAscii '-' >> showpIntAtBase b f (-n)
                      | n == 0    = putAscii (f 0)
                      | otherwise = let
-  go n | n == 0    = return ()
+  go k | k == 0    = return ()
        | otherwise = go d >> putAscii (f $ fromIntegral m)
    where
-   (d, m) = n `divMod` b
+   (d, m) = k `divMod` b
   in go n
